@@ -2,12 +2,10 @@
 
 const inherits = require('inherits');
 const Buffer = require('buffer').Buffer;
-
-const asn1 = require('../../asn1');
-const base = asn1.base;
+const Node = require('../base/node');
 
 // Import DER constants
-const der = asn1.constants.der;
+const der = require('../constants/der');
 
 function DEREncoder(entity) {
   this.enc = 'der';
@@ -27,9 +25,9 @@ DEREncoder.prototype.encode = function encode(data, reporter) {
 // Tree methods
 
 function DERNode(parent) {
-  base.Node.call(this, 'der', parent);
+  Node.call(this, 'der', parent);
 }
-inherits(DERNode, base.Node);
+inherits(DERNode, Node);
 
 DERNode.prototype._encodeComposite = function encodeComposite(tag,
   primitive,
